.ai
.claude
.codex
.cursor
.editorconfig
.env
.env.example
.gitattributes
.gitignore
.kilocode
AGENTS.md
CODE_OF_CONDUCT.md
LICENSE
README.md
UPGRADE.md
app
artisan
bin
bootstrap
composer.json
composer.lock
config
database
example.txt
lang
package.json
packages
phpunit.xml
pint.json
public
resources
routes
storage
tests
vendor
vite.config.js
.htaccess